aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorWesley Miaw <josuah@users.sourceforge.net>2003-09-20 00:17:58 +0000
committerWesley Miaw <josuah@users.sourceforge.net>2003-09-20 00:17:58 +0000
commitff5b7e18e5962839936679141035a49c8e2ff2a6 (patch)
tree65844426af296d7d0f80fe7d51143f585cddefc8
parentafe581186d6bd59ea42e5dfa3ce47ab6705b9409 (diff)
downloadphpicalendar-ff5b7e18e5962839936679141035a49c8e2ff2a6.tar.gz
phpicalendar-ff5b7e18e5962839936679141035a49c8e2ff2a6.tar.bz2
phpicalendar-ff5b7e18e5962839936679141035a49c8e2ff2a6.zip
Forgot to commit change of references to all_calenders_combined971 to
$ALL_CALENDARS_COMBINED for these files.
-rw-r--r--day.php4
-rw-r--r--preferences.php6
-rw-r--r--week.php4
3 files changed, 7 insertions, 7 deletions
diff --git a/preferences.php b/preferences.php
index 91fdccc..dbe664b 100644
--- a/preferences.php
+++ b/preferences.php
@@ -178,10 +178,10 @@ include (BASE.'includes/header.inc.php');
}
// add option to open all (non-web) calenders together
// Todo: add $all_calenders_combined_lang (plural) in the language-specific files and use it here
- if ($cookie_calendar == 'all_calenders_combined971') {
- print "<option value=\"all_calenders_combined971\" selected>$all_cal_comb_lang</option>\n";
+ if ($cookie_calendar == $ALL_CALENDARS_COMBINED) {
+ print "<option value=\"$ALL_CALENDARS_COMBINED\" selected>$all_cal_comb_lang</option>\n";
} else {
- print "<option value=\"all_calenders_combined971\">$all_cal_comb_lang</option>\n";
+ print "<option value=\"$ALL_CALENDARS_COMBINED\">$all_cal_comb_lang</option>\n";
}
foreach($list_webcals as $cal_tmp) {
diff --git a/day.php b/day.php
index 1e01091..8a5a641 100644
--- a/day.php
+++ b/day.php
@@ -250,8 +250,8 @@ include (BASE.'includes/header.inc.php');
echo '<table width="100%" border="0" cellpadding="1" cellspacing="0">'."\n";
echo '<tr>'."\n";
echo '<td class="eventbg_'.$event_calno.'">';
- // Todo: keep track of where the event comes from, and indicate that to openevent instead of "all_calenders_combined971"
- if ($cal == 'all_calenders_combined971') $calendar_name2=$cal; else $calendar_name2=$calendar_name;
+ // Todo: keep track of where the event comes from, and indicate that to openevent instead of $ALL_CALENDARS_COMBINED
+ if ($cal == $ALL_CALENDARS_COMBINED) $calendar_name2=$cal; else $calendar_name2=$calendar_name;
openevent("$calendar_name2",
"$event_start",
"$event_end",
diff --git a/week.php b/week.php
index 768bb1d..09c65af 100644
--- a/week.php
+++ b/week.php
@@ -304,8 +304,8 @@ include (BASE.'includes/header.inc.php');
echo '<td class="eventbg_'.$event_calno.'">';
$event_end = $this_time_arr[($event_length[$thisday][$i]["key"])]["end_unixtime"];
$event_end = date ($timeFormat, $event_end);
- // Todo: keep track of where the event comes from, and indicate that to openevent instead of "all_calenders_combined971"
- if ($cal == 'all_calenders_combined971') $calendar_name2=$cal; else $calendar_name2=$calendar_name;
+ // Todo: keep track of where the event comes from, and indicate that to openevent instead of $ALL_CALENDARS_COMBINED
+ if ($cal == $ALL_CALENDARS_COMBINED) $calendar_name2=$cal; else $calendar_name2=$calendar_name;
openevent("$calendar_name2",
"$event_start",
"$event_end",

© 2014-2024 Faster IT GmbH | imprint | privacy policy